/*******************************************************************************

  Intel Data Center Bridging (DCB) Software
  Copyright(c) 2007-2008 Intel Corporation.

  This program is free software; you can redistribute it and/or modify it
  under the terms and conditions of the GNU General Public License,
  version 2, as published by the Free Software Foundation.

  This program is distributed in the hope it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.

  The full GNU General Public License is included in this distribution in
  the file called "COPYING".

  Contact Information:
  e1000-eedc Mailing List <e1000-eedc@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#ifndef _DCB_PROTOCOL_H_
#define _DCB_PROTOCOL_H_
#include "dcb_types.h"


typedef enum {
	dcb_success = 0,
	dcb_failed,
	dcb_device_not_found,
	dcb_invalid_cmd,
	dcb_bad_params,
	dcb_peer_not_present,
	dcb_ctrl_vers_not_compatible,
	dcb_not_capable
} dcb_result;

#ifdef __cplusplus
extern "C" {
#endif

#define TRY_BEGIN						try{
#define CATCH_END(_param)				}catch(...) {return((_param));}
#define CATCH_END_VOID					}catch(...) {return;}
#define CATCH							}catch(...)


boolean_t add_adapter(char *device_name);
boolean_t remove_adapter(char *device_name);

/* unique strings for default data storage */
#define DEF_CFG_STORE "default_cfg_attribs"  /* Localization OK */

boolean_t add_pg_defaults(void);
boolean_t add_pfc_defaults(void);
boolean_t add_app_defaults(u32 subtype);
boolean_t remove_pg_defaults(void);
boolean_t remove_pfc_defaults(void);
boolean_t remove_app_defaults(void);

void mark_pg_sent(char *device_name);
void mark_pfc_sent(char *device_name);
void mark_app_sent(char *device_name, u32 subtype);

dcb_result get_pg(char *device_name, pg_attribs *pg_data);
dcb_result put_pg(char *device_name, pg_attribs *pg_data);
dcb_result put_peer_pg(char *,  pg_attribs *);
dcb_result get_oper_pg(char *device_name, pg_attribs *pg_data);
dcb_result get_peer_pg(char *device_name, pg_attribs *pg_data);
dcb_result get_pg_dstore(char *device_name, pg_attribs *pg_data);

dcb_result get_pfc(char *device_name, pfc_attribs *pfc_data);
dcb_result put_pfc(char *device_name, pfc_attribs *pfc_data);
dcb_result put_peer_pfc(char *, pfc_attribs *);
dcb_result get_oper_pfc(char *device_name, pfc_attribs *pfc_data);
dcb_result get_peer_pfc(char *device_name, pfc_attribs *pfc_data);
dcb_result get_control(char *device_name,
	control_protocol_attribs *control_data);
dcb_result get_peer_control(char *device_name,
	control_protocol_attribs *control_data);
dcb_result put_peer_control(char *, control_protocol_attribs *);
dcb_result get_all_bwg_descrpts(char *device_name, bwg_descriptions *names);
dcb_result get_bwg_descrpt(char *device_name, u8 bwgid, char **name);
dcb_result put_bwg_descrpt(char *device_name, u8 bwgid, char *name);
dcb_result get_app(char *device_name, u32 subtype, app_attribs *app_data); 
dcb_result put_app(char *device_name, u32 subtype, app_attribs *app_data);
dcb_result put_peer_app(char *device_name, u32 subtype, app_attribs *);
dcb_result get_oper_app(char *device_name, u32 subtype, app_attribs *app_data);
dcb_result get_peer_app(char *device_name, u32 subtype, app_attribs *app_data);

dcb_result dcb_check_config(pg_attribs *pg);

dcb_result run_feature_protocol(char *device_name, u32 EventFlag, u32 Subtype);
dcb_result run_control_protocol(char *device_name, u32 EventFlag);
dcb_result run_dcb_protocol(char *device_name, u32 EventFlag, u32 Subtype);

void remove_all_adapters(void);

boolean_t lock_present(char *device_name);
boolean_t create_dcb_lock(char *device_name);
void delete_dcb_lock(char *device_name);
boolean_t acquire_dcb_lock(char *device_name);
void release_dcb_lock(char *device_name);

boolean_t create_feature_lock(char *device_name);
void delete_feature_lock(char *device_name);
boolean_t acquire_feature_lock(char *device_name);
void release_feature_lock(char *device_name);

void log_message(u32 dwMsgId, char *pFormat, ...);

#ifdef  __cplusplus
}
#endif

#endif //_DCB_PROTOCOL_H_
